Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1906)

Unified Diff: webrtc/test/layer_filtering_transport.h

Issue 1353263005: Adding support for simulcast and spatial layers into VideoQualityTest (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: forgot std:: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/test/layer_filtering_transport.h
diff --git a/webrtc/test/layer_filtering_transport.h b/webrtc/test/layer_filtering_transport.h
index 68994ae38a86edfd4bb9f3fdf3d306eb6e739bac..4de07953b9e01426761dbb07745ae2489fa9de44 100644
--- a/webrtc/test/layer_filtering_transport.h
+++ b/webrtc/test/layer_filtering_transport.h
@@ -13,6 +13,8 @@
#include "webrtc/test/direct_transport.h"
#include "webrtc/test/fake_network_pipe.h"
+#include <map>
+
namespace webrtc {
namespace test {
@@ -22,21 +24,25 @@ class LayerFilteringTransport : public test::DirectTransport {
LayerFilteringTransport(const FakeNetworkPipe::Config& config,
uint8_t vp8_video_payload_type,
uint8_t vp9_video_payload_type,
- uint8_t tl_discard_threshold,
- uint8_t sl_discard_threshold);
+ int selected_tl,
+ int selected_sl);
+ bool DiscardedLastPacket() const;
bool SendRtp(const uint8_t* data,
size_t length,
const PacketOptions& options) override;
private:
+ uint16_t NextSequenceNumber(uint32_t ssrc);
+
// Used to distinguish between VP8 and VP9.
const uint8_t vp8_video_payload_type_;
const uint8_t vp9_video_payload_type_;
- // Discard all temporal/spatial layers with id greater or equal the
- // threshold. 0 to disable.
- const uint8_t tl_discard_threshold_;
- const uint8_t sl_discard_threshold_;
- uint16_t current_seq_num_;
+ // Discard or invalidate all temporal/spatial layers with id greater than the
+ // selected one. -1 to disable filtering.
+ const int selected_tl_;
+ const int selected_sl_;
+ std::map<uint32_t, uint16_t> current_seq_nums_;
mflodman 2015/10/06 11:27:27 Add a comment for the map key.
ivica 2015/10/07 11:59:50 Done.
+ bool discarded_last_packet_;
};
} // namespace test

Powered by Google App Engine
This is Rietveld 408576698